%global year 2017
%global month 02

%global __provides_exclude_from ^.*libperl6_ops_moar\\.so.*$

Name:           rakudo
Version:        0.%{year}.%{month}
Release:        1%{?dist}
Summary:        Perl 6 compiler implementation that runs on MoarVM
License:        Artistic 2.0
URL:            http://rakudo.org/

Source0:        http://rakudo.org/downloads/rakudo/rakudo-%{year}.%{month}.tar.gz
# sources for desktop files are added here
Source1:        ftp://ftp.uni-siegen.de/pub/desk/rakudo.desk.tar.gz

# general BuildRequires
BuildRequires:  perl, make, perl-podlators, coreutils

# general perl-package BuildRequires
BuildRequires:  perl(base), perl(Cwd), perl(Exporter), perl(File::Copy)
BuildRequires:  perl(File::Spec), perl(Getopt::Long), perl(lib), perl(strict)
BuildRequires:  perl(Text::ParseWords), perl(warnings)

# gcc
BuildRequires:  gcc

# general perl-test-package BuildRequires
BuildRequires:  perl(FindBin), perl(List::Util) 

BuildRequires:  perl(ExtUtils::Command)
BuildRequires:  perl(Test::Harness)


# BuildRequires for MoarVM
BuildRequires:  nqp >= 0.0.%{year}.%{month}
Requires:       nqp >= 0.0.%{year}.%{month}
BuildRequires:  moarvm-devel
# Needed for the header files, (#include <uv.h> - libuv-devel)
BuildRequires:  libuv-devel
BuildRequires:  libatomic_ops-devel
BuildRequires:  libtommath-devel


# Needed for desktop-file-install usage
BuildRequires:  desktop-file-utils


%description
Rakudo Perl 6, or just Rakudo, is an implementation of the
Perl 6 language specification. More information about Perl 6 is available
from <http://perl6.org/>. This package provides a Perl 6 compiler built for
MoarVM virtual machine.


%prep
%setup -q -n rakudo-%{year}.%{month}
# install to _libdir/perl6 instead of /usr/share/perl6
%{__sed} -i -e 's#$(PREFIX)/share/perl6#%{_libdir}/perl6#g' tools/build/Makefile-common-macros.in
# install to _libdir/nqp instead of /usr/share/nqp/lib
%{__sed} -i -e "s#nqp::getcomp.*/share/nqp/lib/#'%{_libdir}/nqp/#g" src/Perl6/ModuleLoader.nqp


%build
%{__perl} Configure.pl --prefix=%{_prefix} --backends=moar
# install to _libdir/nqp instead of /usr/share/nqp/lib
%{__sed} -i -e 's#$(PREFIX)/share/nqp/lib#%{_libdir}/nqp#g' Makefile
%{__sed} -i -e 's#/usr/share/nqp/lib#%{_libdir}/nqp#g' Makefile
CFLAGS=$RPM_OPT_FLAGS make %{?_smp_mflags}


%install
CFLAGS=$RPM_OPT_FLAGS %make_install

# Generating man-pages
%{__perl} -MExtUtils::Command -e mkpath $RPM_BUILD_ROOT%{_mandir}/man1
pod2man --section=1 --name=perl6 docs/running.pod | %{__gzip} -c > $RPM_BUILD_ROOT%{_mandir}/man1/perl6.1.gz
pod2man --section=1 --name=perl6-m docs/running.pod | %{__gzip} -c > $RPM_BUILD_ROOT%{_mandir}/man1/perl6-m.1.gz


# install desktop files for the URLs: docs.perl6.org and perl6intro.com
%define DESK_TARGET $RPM_BUILD_ROOT%{_datadir}/applications/
%{__mkdir} -p %{DESK_TARGET}
%{__tar} xzf %{SOURCE1} --directory=%{DESK_TARGET}

desktop-file-install --delete-original \
    --dir=%{DESK_TARGET} %{DESK_TARGET}perl6_doc_link.desktop
desktop-file-install --delete-original \
    --dir=%{DESK_TARGET} %{DESK_TARGET}intro_link.desktop

# remove zero-length files
rm -f $RPM_BUILD_ROOT/%{_libdir}/perl6/precomp/.lock
rm -f $RPM_BUILD_ROOT/%{_libdir}/perl6/repo.lock


%check
%{?!_without_tests:

%ifarch ppc64 ppc64le armv7hl
rm -f t/04-nativecall/02-simple-args.t
%endif

%ifarch armv7hl
rm -f t/04-nativecall/08-callbacks.t
%endif

%{__make} test
}


%files
%doc README.md CREDITS docs/module_management.md docs/ChangeLog
%license LICENSE

%{_bindir}/perl6*
%{_mandir}/man1/perl6.1.gz
%{_mandir}/man1/perl6-m.1.gz

# desktop files
%{_datadir}/applications/perl6_doc_link.desktop
%{_datadir}/applications/intro_link.desktop

%{_libdir}/perl6
%{_libdir}/nqp/Perl6


%changelog
* Wed Mar 15 2017 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2017.02-1
- update to 2017.02
- initial epel7 branch upload

* Thu Mar 09 2017 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2017.01-5
- fix the rakudo-star version that is provided
- group tag removed
- remove zero-length files
- preventing to provides libperl6_ops_moar.so from non-standard path

* Tue Mar 07 2017 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2017.01-4
- install to _libdir/nqp instead of /usr/share/nqp/lib

* Wed Mar 01 2017 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2017.01-3
- install to _libdir/perl6 instead of /usr/share/perl6 

* Thu Feb 23 2017 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2017.01-2
- summary tab, description and operator in obsoletes tag is changed
- dependency on readline-devel is removed
- _prefix marcro is used
- docs/ChangeLog is packaged as documentation
- general build-requires are added

* Tue Feb 21 2017 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2017.01-1
- initial spec file for the new review
